CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
107 lines
3.1 KiB
C++
107 lines
3.1 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
/**
|
|
* @addtogroup hipMallocMipmappedArray hipMallocMipmappedArray
|
|
* @{
|
|
* @ingroup TextureTest
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Negative parameters test for `hipMallocMipmappedArray`.
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/texture/hipMallocMipmappedArray.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.7
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipMallocMipmappedArray_Negative_Parameters) {
|
|
CHECK_IMAGE_SUPPORT;
|
|
|
|
hipMipmappedArray_t array;
|
|
hipChannelFormatDesc desc = hipCreateChannelDesc<float>();
|
|
hipExtent extent = make_hipExtent(4, 4, 6);
|
|
unsigned int levels = 1 + std::log2(extent.depth);
|
|
|
|
SECTION("mipmappedArray is nullptr") {
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(nullptr, &desc, extent, levels, 0),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("desc is nullptr") {
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, nullptr, extent, levels, 0),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("extent is zero") {
|
|
extent = {};
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, &desc, extent, levels, 0),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("invalid flags") {
|
|
HIP_CHECK_ERROR(
|
|
hipMallocMipmappedArray(&array, &desc, extent, levels, static_cast<unsigned int>(-1)),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("hipArrayCubemap && depth != height") {
|
|
extent.height = 5;
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, &desc, extent, levels, hipArrayCubemap),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("hipArrayCubemap && depth != 6") {
|
|
extent.depth = 12;
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, &desc, extent, levels, hipArrayCubemap),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("hipArrayCubemap && hipArrayLayered && depth is not a multiple of 6") {
|
|
extent.depth = 13;
|
|
HIP_CHECK_ERROR(
|
|
hipMallocMipmappedArray(&array, &desc, extent, levels, hipArrayCubemap | hipArrayLayered),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("hipArrayTextureGather && 1D array") {
|
|
extent.height = 0;
|
|
extent.depth = 0;
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, &desc, extent, levels, hipArrayTextureGather),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("hipArrayTextureGather && 3D array") {
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, &desc, extent, levels, hipArrayTextureGather),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
#if HT_NVIDIA // Disabled due to defect EXSWHTEC-365
|
|
SECTION("hipArraySparse && 1D array") {
|
|
extent.height = 0;
|
|
extent.depth = 0;
|
|
HIP_CHECK_ERROR(hipMallocMipmappedArray(&array, &desc, extent, levels, cudaArraySparse),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("hipArraySparse && cubemap array") {
|
|
HIP_CHECK_ERROR(
|
|
hipMallocMipmappedArray(&array, &desc, extent, levels, hipArrayCubemap | cudaArraySparse),
|
|
hipErrorInvalidValue);
|
|
}
|
|
#endif
|
|
}
|
|
|
|
/**
|
|
* End doxygen group TextureTest.
|
|
* @}
|
|
*/
|